@@ -2325,10 +2325,10 @@ def _log_multiple_compat_errors(logger, errors_map):
     if outdated:
         logger.warning(
             "\n        ".join(
-                ["\n   The following extensions are outdated:", *outdated]
-                + [
-                    '\n   Consider running "jupyter labextension update --all" '
-                    "to check for updates.\n"
+                [
+                    "\n   The following extensions are outdated:",
+                    *outdated,
+                    '\n   Consider running "jupyter labextension update --all" to check for updates.\n',
                 ]
             )
         )
